@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 """
 MIT License
 
@@ -29,8 +31,7 @@ __author__ = 'Marseel Eeso'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2022-present Marseel Eeso'
 __version__ = '2.0.0'
-__path__ = __import__('pkgutil').extend_path(__path__, __name__)
-
+# __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
 import aiohttp
 
@@ -45,6 +46,18 @@ API_BASE = "https://opentdb.com/"
 class Client:
 	def __init__(self, session_token: str) -> None:
 		self.session_token = session_token
+		self.session: Optional[aiohttp.ClientSession] = None
+
+	async def __aenter__(self) -> "Client":
+		self.session = aiohttp.ClientSession()
+		return self
+
+	async def __aexit__(self) -> None:
+		await self.session.close()
+
+	async def close_session(self) -> None:
+		assert session is not None
+		await self.session.close()
 
 	@staticmethod
 	async def check_response(response_code: int) -> None:
@@ -72,9 +85,12 @@ class Client:
 
 	async def _request(self, endpoint: str, **params) -> Union[CategoriesList, CategoryQuestionsCount, GlobalQuestionsCount, QuestionResponse]:
 		params['token'] = self.token
-		async with aiohttp.ClientSession() as session:
-			async with session.get(API_BASE + endpoint, params=params) as response:
-				return await response.json()
+
+		if self.session is None:
+			self.session = aiohttp.ClientSession()
+		
+		async with self.session.get(API_BASE + endpoint, params=params) as response:
+			return await response.json()
 
 	async def get_questions(self, 
 		amount: int = 10, 
